Module application

Module application 

Helpers for bootstrapping iced applications with Material defaults.

Functions

application
Creates an iced application with the bundled Material fonts preloaded.
window
Returns centered window settings for the provided size.
window_settings
Returns centered window settings with the provided size constraints.
window_with_min_size
Returns centered window settings with the provided minimum size.
with_material_fonts
Adds the bundled Material fonts to an existing iced application.