pub struct ColorScheme {
pub primary: ColorQuartet,
pub secondary: ColorQuartet,
pub tertiary: ColorQuartet,
pub error: ColorQuartet,
pub surface: Surface,
pub inverse: Inverse,
pub outline: Outline,
pub shadow: Color,
pub scrim: Color,
}Expand description
A Theme’s color scheme.
These color roles are based on Material Design 3. For more information about them, visit the official M3 documentation.
Fields
primary: ColorQuartetThe primary colors.
secondary: ColorQuartetThe secondary colors.
tertiary: ColorQuartetThe tertiary colors.
error: ColorQuartetThe error colors.
surface: SurfaceThe surface colors.
inverse: InverseThe inverse colors.
outline: OutlineThe outline colors.
shadow: ColorThe shadow color.
scrim: ColorThe scrim color.
Implementations
Sourceimpl ColorScheme
impl ColorScheme
pub fn interpolate(from: Self, to: Self, amount: f32) -> Self