Button

Struct Button 

pub struct Button<'a, Message, Renderer = Renderer>
where Renderer: Renderer,
{ /* private fields */ }
A Material 3 button with Android-style bounded press ripples.

Implementations

Source

impl<'a, Message, Renderer> Button<'a, Message, Renderer>
where Message: Clone + 'a, Renderer: Renderer + 'a,

pub fn new(content: impl Into<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a new Button with the given content.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Button.

pub fn height(self, height: impl Into<Length>) -> Self

Sets the height of the Button.

pub fn padding<P: Into<Padding>>(self, padding: P) -> Self

Sets the Padding of the Button.

pub fn on_press(self, on_press: Message) -> Self

Sets the message produced when the Button is pressed.

Examples found in repository?
examples/quickstart/app.rs (line 79)
72    fn view(self, app: &App) -> material::Element<'_, Message> {
73        match self {
74            Self::Home => page::surface(
75                page::header("Home", "A small Material app"),
76                column![
77                    material::text::headline_medium(app.count.to_string()),
78                    button::button("Increment", button::ButtonVariant::Filled)
79                        .on_press(Message::Increment),
80                    button::button("Decrement", button::ButtonVariant::Outlined)
81                        .on_press(Message::Decrement),
82                ]
83                .spacing(12),
84            )
85            .into(),
86            Self::Settings => page::surface(
87                page::header("Settings", "Pages are enum variants"),
88                material::text::body_large("Use the menu button in the rail"),
89            )
90            .into(),
91        }
92    }
More examples
Hide additional examples
examples/showcase/pages/structure.rs (line 129)
96fn toolbars() -> material::Element<'static, Message> {
97    use material::widget::button::{self, FabSize, FabVariant};
98    use material::widget::toolbar;
99
100    let docked = toolbar::docked(toolbar::icon_actions([
101        ("arrow_back", Message::Decrement),
102        ("arrow_forward", Message::Increment),
103        ("add", Message::Increment),
104        ("tab", Message::Increment),
105        ("star", Message::Increment),
106        ("search", Message::Increment),
107    ]));
108
109    let docked_vibrant = toolbar::docked_vibrant([
110        toolbar::vibrant_icon_action("edit", Message::Increment),
111        toolbar::selected_vibrant_icon_action("check", Message::Increment),
112        toolbar::vibrant_icon_action("delete", Message::Decrement),
113        toolbar::vibrant_icon_action("more_vert", Message::MenuPressed),
114    ]);
115
116    let floating = toolbar::floating([
117        toolbar::selected_icon_action("format_bold", Message::Increment),
118        toolbar::icon_action("format_italic", Message::Increment),
119        toolbar::icon_action("format_underlined", Message::Increment),
120        toolbar::icon_action("format_color_text", Message::Increment),
121    ]);
122
123    let floating_vibrant = toolbar::floating_with_fab(
124        toolbar::floating_vibrant(toolbar::vibrant_icon_actions([
125            ("share", Message::Increment),
126            ("add", Message::Increment),
127            ("edit", Message::Increment),
128        ])),
129        button::fab("search", FabVariant::Primary, FabSize::Standard).on_press(Message::Increment),
130    );
131
132    let vertical = toolbar::vertical_floating([
133        toolbar::icon_action("undo", Message::Decrement),
134        toolbar::icon_action("redo", Message::Increment),
135        toolbar::selected_icon_action("palette", Message::Increment),
136    ]);
137
138    page::component_stack([
139        docked.into(),
140        docked_vibrant.into(),
141        page::row([floating.into(), vertical.into()]).into(),
142        floating_vibrant.into(),
143    ])
144    .into()
145}
pub fn on_press_with(self, on_press: impl Fn() -> Message + 'a) -> Self

Sets the message produced when the Button is pressed using a closure.

pub fn on_press_maybe(self, on_press: Option<Message>) -> Self

Sets the message produced when the Button is pressed, if any.

pub fn clip(self, clip: bool) -> Self

Sets whether the button content should be clipped on overflow.

pub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self

Sets the style of the Button.