Combobox

Struct Combobox 

pub struct Combobox<'a, T, Message, Renderer>
where T: Display + Clone, Renderer: Renderer,
{ /* private fields */ }
Material combobox.

Implementations

Source

impl<'a, T, Message, Renderer> Combobox<'a, T, Message, Renderer>
where T: Display + Clone + 'static, Renderer: Renderer + 'a,

pub fn on_input(self, on_input: impl Fn(String) -> Message + 'static) -> Self

Sets the message that should be produced when text is typed.

Examples found in repository?
examples/showcase/pages/inputs.rs (line 31)
6pub(super) fn view(state: &Showcase) -> material::Element<'_, Message> {
7    let input = material::widget::text_input::outlined("Write a note", &state.note)
8        .on_input(Message::TextChanged);
9
10    let editor = material::widget::text_editor::outlined_area(&state.editor_content)
11        .placeholder("Write details")
12        .on_action(Message::EditorAction);
13
14    let select_options = ["Assist", "Suggestion", "Filter"];
15    let select = material::widget::select::outlined(
16        select_options,
17        state.select_choice,
18        Message::SelectChanged,
19    )
20    .placeholder("Choose a chip")
21    .label("Chip type");
22
23    let combobox = material::widget::combobox::outlined_with_input(
24        &state.combobox_options,
25        "Search a chip",
26        &state.combobox_input,
27        state.combobox_choice.as_ref(),
28        Message::ComboboxSelected,
29    )
30    .label("Searchable chip")
31    .on_input(Message::ComboboxInputChanged);
32
33    page::sections([
34        page::section("Text fields", page::stack([input.into(), editor.into()])).into(),
35        page::section(
36            "Selection fields",
37            page::stack([select.into(), combobox.into()]),
38        )
39        .into(),
40        page::section("Pickers", pickers(state)).into(),
41        page::section("Search", search_bar(state)).into(),
42        page::section("Dividers", dividers()).into(),
43    ])
44    .into()
45}
pub fn on_option_hovered( self, on_option_hovered: impl Fn(T) -> Message + 'static, ) -> Self

Sets the message that will be produced when an option is hovered.

pub fn on_open(self, message: Message) -> Self

Sets the message that will be produced when the combobox opens.

pub fn on_close(self, message: Message) -> Self

Sets the message that will be produced when the combobox closes.

pub fn label(self, label: impl Into<String>) -> Self

Sets the floating label of the combobox.

Examples found in repository?
examples/showcase/pages/inputs.rs (line 30)
6pub(super) fn view(state: &Showcase) -> material::Element<'_, Message> {
7    let input = material::widget::text_input::outlined("Write a note", &state.note)
8        .on_input(Message::TextChanged);
9
10    let editor = material::widget::text_editor::outlined_area(&state.editor_content)
11        .placeholder("Write details")
12        .on_action(Message::EditorAction);
13
14    let select_options = ["Assist", "Suggestion", "Filter"];
15    let select = material::widget::select::outlined(
16        select_options,
17        state.select_choice,
18        Message::SelectChanged,
19    )
20    .placeholder("Choose a chip")
21    .label("Chip type");
22
23    let combobox = material::widget::combobox::outlined_with_input(
24        &state.combobox_options,
25        "Search a chip",
26        &state.combobox_input,
27        state.combobox_choice.as_ref(),
28        Message::ComboboxSelected,
29    )
30    .label("Searchable chip")
31    .on_input(Message::ComboboxInputChanged);
32
33    page::sections([
34        page::section("Text fields", page::stack([input.into(), editor.into()])).into(),
35        page::section(
36            "Selection fields",
37            page::stack([select.into(), combobox.into()]),
38        )
39        .into(),
40        page::section("Pickers", pickers(state)).into(),
41        page::section("Search", search_bar(state)).into(),
42        page::section("Dividers", dividers()).into(),
43    ])
44    .into()
45}
pub fn padding(self, padding: impl Into<Padding>) -> Self

Sets the padding.

pub fn font(self, font: Renderer::Font) -> Self

Sets the font.

pub fn icon(self, icon: Icon<Renderer::Font>) -> Self

Sets the trailing icon.

pub fn size(self, size: impl Into<Pixels>) -> Self

Sets the text size.

pub fn line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the text line height.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width.

pub fn menu_height(self, menu_height: impl Into<Length>) -> Self

Sets the menu height.

pub fn text_shaping(self, shaping: Shaping) -> Self

Sets the text shaping strategy.

pub fn input_style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the input style.

pub fn menu_style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where <Theme as Catalog>::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the menu style.