pub struct AlertOptions<'a> {
pub icon: Option<Fragment<'a>>,
pub alpha: f32,
}Expand description
Visual options for alert dialog content.
Fields
icon: Option<Fragment<'a>>alpha: f32Implementations
Sourceimpl<'a> AlertOptions<'a>
impl<'a> AlertOptions<'a>
Sourcepub fn icon(self, icon: impl IntoFragment<'a>) -> Self
pub fn icon(self, icon: impl IntoFragment<'a>) -> Self
Sets the optional hero icon slot.
Examples found in repository?
examples/showcase/app.rs (line 651)
632fn alert_dialog(alpha: f32) -> material::Element<'static, Message> {
633 let action_options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
634
635 material::widget::dialog::alert_with(
636 "Discard draft?",
637 "Your current changes will be removed from this device.",
638 material::widget::dialog::actions([
639 material::widget::dialog::action_button_with(
640 "Cancel",
641 Message::DialogDismissed,
642 action_options,
643 ),
644 material::widget::dialog::action_button_with(
645 "Discard",
646 Message::DialogConfirmed,
647 action_options,
648 ),
649 ]),
650 material::widget::dialog::AlertOptions::default()
651 .icon("info")
652 .alpha(alpha),
653 )
654 .into()
655}Sourcepub fn alpha(self, alpha: f32) -> Self
pub fn alpha(self, alpha: f32) -> Self
Sets the Android window alpha applied to the alert content.
Examples found in repository?
examples/showcase/app.rs (line 652)
632fn alert_dialog(alpha: f32) -> material::Element<'static, Message> {
633 let action_options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
634
635 material::widget::dialog::alert_with(
636 "Discard draft?",
637 "Your current changes will be removed from this device.",
638 material::widget::dialog::actions([
639 material::widget::dialog::action_button_with(
640 "Cancel",
641 Message::DialogDismissed,
642 action_options,
643 ),
644 material::widget::dialog::action_button_with(
645 "Discard",
646 Message::DialogConfirmed,
647 action_options,
648 ),
649 ]),
650 material::widget::dialog::AlertOptions::default()
651 .icon("info")
652 .alpha(alpha),
653 )
654 .into()
655}Trait Implementations
Sourceimpl<'a> Clone for AlertOptions<'a>
impl<'a> Clone for AlertOptions<'a>
Sourcefn clone(&self) -> AlertOptions<'a>
fn clone(&self) -> AlertOptions<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for AlertOptions<'a>
impl<'a> Debug for AlertOptions<'a>
Sourceimpl Default for AlertOptions<'_>
impl Default for AlertOptions<'_>
Sourceimpl<'a> PartialEq for AlertOptions<'a>
impl<'a> PartialEq for AlertOptions<'a>
impl<'a> StructuralPartialEq for AlertOptions<'a>