pub struct AlphaOptions {
pub alpha: f32,
}Expand description
Visual options for dialog pieces that only need an alpha override.
Fields
alpha: f32Implementations
Sourceimpl AlphaOptions
impl AlphaOptions
Sourcepub fn alpha(self, alpha: f32) -> Self
pub fn alpha(self, alpha: f32) -> Self
Sets the Android window alpha applied to the dialog piece.
Examples found in repository?
examples/showcase/app.rs (line 702)
679fn login_dialog(state: &Showcase, alpha: f32) -> material::Element<'_, Message> {
680 let body = iced::widget::Column::new()
681 .spacing(material::widget::page::STACK_SPACING)
682 .push(
683 material::widget::text_input::outlined("Account", &state.dialog_account)
684 .id(dialog_account_input_id())
685 .on_input(Message::DialogAccountChanged)
686 .alpha(alpha),
687 )
688 .push(
689 material::widget::text_input::outlined("Password", &state.dialog_password)
690 .secure(true)
691 .on_input(Message::DialogPasswordChanged)
692 .on_submit(Message::DialogConfirmed)
693 .alpha(alpha),
694 )
695 .push(material::widget::checkbox::standard_with_alpha(
696 state.dialog_remember_password,
697 "Remember password",
698 Message::DialogRememberPasswordChanged,
699 alpha,
700 ));
701
702 let options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
703
704 material::widget::dialog::content_with(
705 "Sign in",
706 body,
707 material::widget::dialog::actions([
708 material::widget::dialog::action_button_with(
709 "Cancel",
710 Message::DialogDismissed,
711 options,
712 ),
713 material::widget::dialog::action_button_with(
714 "Log in",
715 Message::DialogConfirmed,
716 options,
717 ),
718 ]),
719 options,
720 )
721 .into()
722}Trait Implementations
Sourceimpl Clone for AlphaOptions
impl Clone for AlphaOptions
Sourcefn clone(&self) -> AlphaOptions
fn clone(&self) -> AlphaOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AlphaOptions
Sourceimpl Debug for AlphaOptions
impl Debug for AlphaOptions
Sourceimpl Default for AlphaOptions
impl Default for AlphaOptions
Sourceimpl PartialEq for AlphaOptions
impl PartialEq for AlphaOptions
impl StructuralPartialEq for AlphaOptions