Material 3 outlined segmented button constructors.
Structs
- State
- Animated segmented button selection state.
Enums
- Segment
Position - A segment’s visual position inside a segmented button set.
Functions
- animated_
label_ action - Creates an animated label segment with an action message.
- animated_
label_ actions - Creates animated label segments from the given selection state and actions.
- animated_
selectable_ label - Creates a label segment with animated selected check icon and fill progress.
- group
- Creates a row that holds segmented buttons with overlapping outlines.
- label
- Creates a label-only outlined segment.
- leading_
icon - Creates an outlined segment with a Material Symbols leading icon.
- segmented_
style - Returns the style for an outlined segmented button.
- segmented_
style_ progress - Returns the style for an outlined segmented button at a selected-state progress.
- selectable_
label - Creates a label segment that shows the Material selected check icon only when selected.