standard_bottom

Function standard_bottom 

pub fn standard_bottom<'a, Message, Renderer>(
    content: impl Into<Element<'a, Message, Theme, Renderer>>,
) -> Container<'a, Message, Theme, Renderer>
where Message: 'a, Renderer: Renderer + Renderer + 'a,
Examples found in repository?
examples/showcase/pages/structure.rs (lines 149-152)
147fn bottom_sheets(state: &Showcase) -> material::Element<'static, Message> {
148    let width = page::preview_width(state.window_size.width);
149    let standard = material::widget::sheet::standard_bottom(sheet_content(
150        "Standard bottom sheet",
151        "Coexists with the page and keeps secondary content available.",
152    ));
153
154    let modal_preview = page::preview_pane(material::widget::sheet::modal_overlay(sheet_content(
155        "Modal bottom sheet",
156        "Uses a scrim and blocks interaction behind the sheet.",
157    )));
158
159    page::component_stack([
160        page::centered_preview(width, standard).into(),
161        page::centered_preview(width, modal_preview).into(),
162    ])
163    .into()
164}