pub struct HostOptions {
pub bottom_margin: f32,
}Expand description
Layout options for a snackbar host.
Fields
bottom_margin: f32Distance between the snackbar bottom edge and the host bottom edge.
Implementations
Sourceimpl HostOptions
impl HostOptions
Sourcepub fn bottom_margin(self, bottom_margin: f32) -> Self
pub fn bottom_margin(self, bottom_margin: f32) -> Self
Sets the distance between the snackbar and the host bottom edge.