pub fn bottom_margin(layout: AdaptiveLayout) -> f32Expand description
Returns the floating control bottom margin after accounting for an adaptive navigation layout.
pub fn bottom_margin(layout: AdaptiveLayout) -> f32Returns the floating control bottom margin after accounting for an adaptive navigation layout.