pub struct State { /* private fields */ }Implementations
Sourceimpl State
impl State
pub const fn new() -> Self
pub const fn is_open(self) -> bool
pub const fn is_animating(self) -> bool
Sourcepub fn floating_clearance(self) -> f32
pub fn floating_clearance(self) -> f32
Returns the vertical space occupied by the floating button and the currently revealed picker panel above its bottom margin.
pub fn advance(&mut self, now: Instant) -> bool
pub fn toggle(&mut self)
pub fn open(&mut self)
pub fn close(&mut self)