pub enum ColorMode {
Standard,
Vibrant,
}Expand description
The Material color configuration used by a toolbar and its actions.
Variants
Standard
Low-emphasis toolbar color for keeping attention on page content.
Vibrant
High-emphasis toolbar color for prominent or temporary page modes.