Helpers for bootstrapping iced applications with Material defaults.
Functions
- application
- Creates an
icedapplication with the bundled Material fonts preloaded. - window
- Returns centered window settings for the provided size.
- window_
settings - Returns centered window settings with the provided size constraints.
- window_
with_ min_ size - Returns centered window settings with the provided minimum size.
- with_
material_ fonts - Adds the bundled Material fonts to an existing
icedapplication.