pub struct AlertOptions<'a> {
pub icon: Option<Fragment<'a>>,
pub alpha: f32,
}Expand description
Visual options for alert dialog content.
Fields
icon: Option<Fragment<'a>>alpha: f32Implementations
Sourceimpl<'a> AlertOptions<'a>
impl<'a> AlertOptions<'a>
Sourcepub fn icon(self, icon: impl IntoFragment<'a>) -> Self
pub fn icon(self, icon: impl IntoFragment<'a>) -> Self
Sets the optional hero icon slot.
Examples found in repository?
examples/showcase/app.rs (line 453)
434fn alert_dialog(alpha: f32) -> material::Element<'static, Message> {
435 let action_options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
436
437 material::widget::dialog::alert_with(
438 "Discard draft?",
439 "Your current changes will be removed from this device.",
440 material::widget::dialog::actions([
441 material::widget::dialog::action_button_with(
442 "Cancel",
443 Message::DialogDismissed,
444 action_options,
445 ),
446 material::widget::dialog::action_button_with(
447 "Discard",
448 Message::DialogConfirmed,
449 action_options,
450 ),
451 ]),
452 material::widget::dialog::AlertOptions::default()
453 .icon("info")
454 .alpha(alpha),
455 )
456 .into()
457}Sourcepub fn alpha(self, alpha: f32) -> Self
pub fn alpha(self, alpha: f32) -> Self
Sets the Android window alpha applied to the alert content.
Examples found in repository?
examples/showcase/app.rs (line 454)
434fn alert_dialog(alpha: f32) -> material::Element<'static, Message> {
435 let action_options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
436
437 material::widget::dialog::alert_with(
438 "Discard draft?",
439 "Your current changes will be removed from this device.",
440 material::widget::dialog::actions([
441 material::widget::dialog::action_button_with(
442 "Cancel",
443 Message::DialogDismissed,
444 action_options,
445 ),
446 material::widget::dialog::action_button_with(
447 "Discard",
448 Message::DialogConfirmed,
449 action_options,
450 ),
451 ]),
452 material::widget::dialog::AlertOptions::default()
453 .icon("info")
454 .alpha(alpha),
455 )
456 .into()
457}Trait Implementations
Sourceimpl<'a> Clone for AlertOptions<'a>
impl<'a> Clone for AlertOptions<'a>
Sourcefn clone(&self) -> AlertOptions<'a>
fn clone(&self) -> AlertOptions<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for AlertOptions<'a>
impl<'a> Debug for AlertOptions<'a>
Sourceimpl Default for AlertOptions<'_>
impl Default for AlertOptions<'_>
Sourceimpl<'a> PartialEq for AlertOptions<'a>
impl<'a> PartialEq for AlertOptions<'a>
Sourcefn eq(&self, other: &AlertOptions<'a>) -> bool
fn eq(&self, other: &AlertOptions<'a>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<'a> StructuralPartialEq for AlertOptions<'a>