pub struct AlphaOptions {
pub alpha: f32,
}Expand description
Visual options for dialog pieces that only need an alpha override.
Fields
alpha: f32Implementations
Sourceimpl AlphaOptions
impl AlphaOptions
Sourcepub fn alpha(self, alpha: f32) -> Self
pub fn alpha(self, alpha: f32) -> Self
Sets the Android window alpha applied to the dialog piece.
Examples found in repository?
examples/showcase/app.rs (line 435)
434fn alert_dialog(alpha: f32) -> material::Element<'static, Message> {
435 let action_options = material::widget::dialog::AlphaOptions::default().alpha(alpha);
436
437 material::widget::dialog::alert_with(
438 "Discard draft?",
439 "Your current changes will be removed from this device.",
440 material::widget::dialog::actions([
441 material::widget::dialog::action_button_with(
442 "Cancel",
443 Message::DialogDismissed,
444 action_options,
445 ),
446 material::widget::dialog::action_button_with(
447 "Discard",
448 Message::DialogConfirmed,
449 action_options,
450 ),
451 ]),
452 material::widget::dialog::AlertOptions::default()
453 .icon("info")
454 .alpha(alpha),
455 )
456 .into()
457}Trait Implementations
Sourceimpl Clone for AlphaOptions
impl Clone for AlphaOptions
Sourcefn clone(&self) -> AlphaOptions
fn clone(&self) -> AlphaOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AlphaOptions
Sourceimpl Debug for AlphaOptions
impl Debug for AlphaOptions
Sourceimpl Default for AlphaOptions
impl Default for AlphaOptions
Sourceimpl PartialEq for AlphaOptions
impl PartialEq for AlphaOptions
Sourcefn eq(&self, other: &AlphaOptions) -> bool
fn eq(&self, other: &AlphaOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AlphaOptions