Module segmented_button

Module segmented_button 

Material 3 outlined segmented button constructors.

Structs

State
Animated segmented button selection state.

Enums

SegmentPosition
A segment’s visual position inside a segmented button set.

Functions

animated_label_action
Creates an animated label segment with an action message.
animated_label_actions
Creates animated label segments from the given selection state and actions.
animated_selectable_label
Creates a label segment with animated selected check icon and fill progress.
group
Creates a row that holds segmented buttons with overlapping outlines.
label
Creates a label-only outlined segment.
leading_icon
Creates an outlined segment with a Material Symbols leading icon.
segmented_style
Returns the style for an outlined segmented button.
segmented_style_progress
Returns the style for an outlined segmented button at a selected-state progress.
selectable_label
Creates a label segment that shows the Material selected check icon only when selected.