pub struct Select<'a, T, L, V, Message, Renderer>{ /* private fields */ }Expand description
A Material select field.
Implementations
Sourceimpl<'a, T, L, V, Message, Renderer> Select<'a, T, L, V, Message, Renderer>
impl<'a, T, L, V, Message, Renderer> Select<'a, T, L, V, Message, Renderer>
Sourcepub fn new(
options: L,
selected: Option<V>,
on_select: impl Fn(T) -> Message + 'a,
) -> Self
pub fn new( options: L, selected: Option<V>, on_select: impl Fn(T) -> Message + 'a, ) -> Self
Creates a new Select with the given list of options, selected value,
and message to produce when an option is selected.
Sourcepub fn placeholder(self, placeholder: impl Into<String>) -> Self
pub fn placeholder(self, placeholder: impl Into<String>) -> Self
Sets the placeholder of the select.
Examples found in repository?
examples/showcase/pages/inputs.rs (line 20)
6pub(super) fn view(state: &Showcase) -> material::Element<'_, Message> {
7 let input = material::widget::text_input::outlined("Write a note", &state.note)
8 .on_input(Message::TextChanged);
9
10 let editor = material::widget::text_editor::outlined_area(&state.editor_content)
11 .placeholder("Write details")
12 .on_action(Message::EditorAction);
13
14 let select_options = ["Assist", "Suggestion", "Filter"];
15 let select = material::widget::select::outlined(
16 select_options,
17 state.select_choice,
18 Message::SelectChanged,
19 )
20 .placeholder("Choose a chip")
21 .label("Chip type");
22
23 let combobox = material::widget::combobox::outlined_with_input(
24 &state.combobox_options,
25 "Search a chip",
26 &state.combobox_input,
27 state.combobox_choice.as_ref(),
28 Message::ComboboxSelected,
29 )
30 .label("Searchable chip")
31 .on_input(Message::ComboboxInputChanged);
32
33 page::sections([
34 page::section("Text fields", page::stack([input.into(), editor.into()])).into(),
35 page::section(
36 "Selection fields",
37 page::stack([select.into(), combobox.into()]),
38 )
39 .into(),
40 page::section("Pickers", pickers(state)).into(),
41 page::section("Search", search_bar(state)).into(),
42 page::section("Dividers", dividers()).into(),
43 ])
44 .into()
45}Sourcepub fn label(self, label: impl Into<String>) -> Self
pub fn label(self, label: impl Into<String>) -> Self
Sets the floating label of the select.
Examples found in repository?
examples/showcase/pages/inputs.rs (line 21)
6pub(super) fn view(state: &Showcase) -> material::Element<'_, Message> {
7 let input = material::widget::text_input::outlined("Write a note", &state.note)
8 .on_input(Message::TextChanged);
9
10 let editor = material::widget::text_editor::outlined_area(&state.editor_content)
11 .placeholder("Write details")
12 .on_action(Message::EditorAction);
13
14 let select_options = ["Assist", "Suggestion", "Filter"];
15 let select = material::widget::select::outlined(
16 select_options,
17 state.select_choice,
18 Message::SelectChanged,
19 )
20 .placeholder("Choose a chip")
21 .label("Chip type");
22
23 let combobox = material::widget::combobox::outlined_with_input(
24 &state.combobox_options,
25 "Search a chip",
26 &state.combobox_input,
27 state.combobox_choice.as_ref(),
28 Message::ComboboxSelected,
29 )
30 .label("Searchable chip")
31 .on_input(Message::ComboboxInputChanged);
32
33 page::sections([
34 page::section("Text fields", page::stack([input.into(), editor.into()])).into(),
35 page::section(
36 "Selection fields",
37 page::stack([select.into(), combobox.into()]),
38 )
39 .into(),
40 page::section("Pickers", pickers(state)).into(),
41 page::section("Search", search_bar(state)).into(),
42 page::section("Dividers", dividers()).into(),
43 ])
44 .into()
45}Sets the height of the menu.
Sourcepub fn padding(self, padding: impl Into<Padding>) -> Self
pub fn padding(self, padding: impl Into<Padding>) -> Self
Sets the padding of the select field.
Sourcepub fn option_padding(self, padding: impl Into<Padding>) -> Self
pub fn option_padding(self, padding: impl Into<Padding>) -> Self
Sets the padding of each menu option.
Sourcepub fn text_size(self, size: impl Into<Pixels>) -> Self
pub fn text_size(self, size: impl Into<Pixels>) -> Self
Sets the text size of the select and its menu items.
Sourcepub fn text_line_height(self, line_height: impl Into<LineHeight>) -> Self
pub fn text_line_height(self, line_height: impl Into<LineHeight>) -> Self
Sets the text line height of the select and its menu items.
Sourcepub fn text_shaping(self, shaping: Shaping) -> Self
pub fn text_shaping(self, shaping: Shaping) -> Self
Sets the text shaping strategy.
Sourcepub fn on_open(self, on_open: Message) -> Self
pub fn on_open(self, on_open: Message) -> Self
Sets the message produced when the menu is opened.
Sourcepub fn on_close(self, on_close: Message) -> Self
pub fn on_close(self, on_close: Message) -> Self
Sets the message produced when the menu is closed.
Sourcepub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
pub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
Sets the style of the select.
Sets the style of the menu.