pub fn standard_bottom<'a, Message, Renderer>(
content: impl Into<Element<'a, Message, Theme, Renderer>>,
) -> Container<'a, Message, Theme, Renderer>Examples found in repository?
examples/showcase/pages/structure.rs (lines 148-151)
146fn bottom_sheets(state: &Showcase) -> material::Element<'static, Message> {
147 let width = page::preview_width(state.window_size.width);
148 let standard = material::widget::sheet::standard_bottom(sheet_content(
149 "Standard bottom sheet",
150 "Coexists with the page and keeps secondary content available.",
151 ));
152
153 let modal_preview = page::preview_pane(material::widget::sheet::modal_overlay(sheet_content(
154 "Modal bottom sheet",
155 "Uses a scrim and blocks interaction behind the sheet.",
156 )));
157
158 page::component_stack([
159 page::centered_preview(width, standard).into(),
160 page::centered_preview(width, modal_preview).into(),
161 ])
162 .into()
163}